@@ -1029,10 +1029,9 @@ eel_background_set_image_uri_sync (EelBackground *background, const char *image_
 static void
 set_image_and_color_image_loading_done_callback (EelBackground *background, gboolean successful_load, char *color)
 {
-	g_signal_handlers_disconnect_by_func (
-		G_OBJECT (background),
-		G_CALLBACK (set_image_and_color_image_loading_done_callback),
-		(gpointer) color);
+	g_signal_handlers_disconnect_by_func
+		(G_OBJECT (background),
+		 G_CALLBACK (set_image_and_color_image_loading_done_callback), color);
 
 	eel_background_set_color_no_emit (background, color);
 
@@ -1061,10 +1060,8 @@ eel_background_set_image_uri_and_color (EelBackground *background, const char *i
 
 	color_copy = g_strdup (color);
 
-	g_signal_connect (background,
-			    "image_loading_done",
-			    G_CALLBACK (set_image_and_color_image_loading_done_callback),
-			    (gpointer) color_copy);
+	g_signal_connect (background, "image_loading_done",
+			  G_CALLBACK (set_image_and_color_image_loading_done_callback), color_copy);
 			    
 	/* set_image_and_color_image_loading_done_callback must always be called
 	 * because we rely on it to:
