@@ -110,7 +110,7 @@ preferences_item_finalize (GObject *object)
 	eel_string_list_free (item->details->enumeration_list_unique_exceptions);
 	g_free (item->details);
 
-	G_OBJECT_CLASS(object)->finalize (object);
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 /*
@@ -127,7 +127,7 @@ preferences_item_update_enumeration_radio (EelPreferencesItem *item)
 	g_return_if_fail (item->details->item_type == EEL_PREFERENCE_ITEM_ENUMERATION_VERTICAL_RADIO
 			  || item->details->item_type == EEL_PREFERENCE_ITEM_ENUMERATION_HORIZONTAL_RADIO);
 
- 	value = eel_preferences_get_integer (item->details->preference_name);
+ 	value = eel_preferences_get_enum (item->details->preference_name);
 
 	enumeration_id = eel_preferences_get_enumeration_id (item->details->preference_name);
 	g_return_if_fail (eel_strlen (enumeration_id) > 0);
@@ -380,7 +380,7 @@ preferences_item_create_enumeration_list (EelPreferencesItem *item,
 	char *enumeration_id;
 	char *enum_description;
 	GConfValue *fallback;
-	EelStringList *default_value;
+	EelStringList *default_value, *string_list;
 	guint num_pickers;
 	GtkWidget *string_picker;
 	GtkWidget *picker_box;
@@ -431,19 +431,23 @@ preferences_item_create_enumeration_list (EelPreferencesItem *item,
 	for (j = 0; j < num_pickers; j++) {
 		string_picker = eel_string_picker_new ();
 		eel_caption_set_show_title (EEL_CAPTION (string_picker), FALSE);
-		
+
+		string_list = eel_string_list_new (TRUE);
 		for (i = 0; i < eel_enumeration_id_get_length (enumeration_id); i++) {
 			enum_description = eel_enumeration_id_get_nth_description_translated (enumeration_id, i);
 			g_assert (enum_description != NULL);
 
 			if (enum_description[0] == '-') {
-				eel_string_picker_insert_separator (EEL_STRING_PICKER (string_picker));
+				eel_string_list_insert (string_list, EEL_STRING_PICKER_SEPARATOR_STRING);
 			} else {
-				eel_string_picker_insert_string (EEL_STRING_PICKER (string_picker), enum_description);
+				eel_string_list_insert (string_list, enum_description);
 			}
 			g_free (enum_description);
 		}
 
+		eel_string_picker_set_string_list (EEL_STRING_PICKER (string_picker), string_list);
+		eel_string_list_free (string_list);
+		
 		gtk_box_pack_start (GTK_BOX (picker_box),
 				    string_picker,
 				    FALSE,
@@ -499,7 +503,8 @@ preferences_item_update_editable_string (EelPreferencesItem *item)
 	char *current_value;
 
 	g_return_if_fail (EEL_IS_PREFERENCES_ITEM (item));
-	g_return_if_fail (item->details->item_type == EEL_PREFERENCE_ITEM_EDITABLE_STRING);
+	g_return_if_fail (item->details->item_type == EEL_PREFERENCE_ITEM_EDITABLE_STRING ||
+		          item->details->item_type == EEL_PREFERENCE_ITEM_EDITABLE_PASSWORD_STRING);
 
 	current_value = eel_preferences_get (item->details->preference_name);
 
@@ -514,7 +519,7 @@ preferences_item_update_editable_string (EelPreferencesItem *item)
 }
 
 static void
-preferences_item_create_editable_string (EelPreferencesItem *item)
+preferences_item_create_editable_string (EelPreferencesItem *item, gboolean password_string)
 {
 	GtkWidget *child;
 	
@@ -532,6 +537,10 @@ preferences_item_create_editable_string (EelPreferencesItem *item)
  	}
 	
 	eel_caption_set_title_label (EEL_CAPTION (child), "");
+
+	if (password_string) {
+		eel_text_caption_set_visibility (EEL_TEXT_CAPTION (child), FALSE);
+	}
 	
 	preferences_item_add_connection_child (item,
 					       child,
@@ -598,7 +607,7 @@ preferences_item_update_enumeration_menu (EelPreferencesItem *item)
 	g_return_if_fail (eel_strlen (enumeration_id) > 0);
 	g_return_if_fail (eel_enumeration_id_get_length (enumeration_id) > 0);
 
-	current_value = eel_preferences_get_integer (item->details->preference_name);
+	current_value = eel_preferences_get_enum (item->details->preference_name);
 
 	position = eel_enumeration_id_get_value_position (enumeration_id,
 							  current_value);
@@ -626,6 +635,7 @@ preferences_item_create_enumeration_menu (EelPreferencesItem *item)
  	guint i;
 	char *enumeration_id;
 	GtkWidget *child;
+	EelStringList *string_list;
 	char *enum_description;
 	
 	g_return_if_fail (EEL_IS_PREFERENCES_ITEM (item));
@@ -637,22 +647,27 @@ preferences_item_create_enumeration_menu (EelPreferencesItem *item)
 	enumeration_id = eel_preferences_get_enumeration_id (item->details->preference_name);
 	g_return_if_fail (eel_strlen (enumeration_id) > 0);
 	g_return_if_fail (eel_enumeration_id_get_length (enumeration_id) > 0);
+
+	string_list = eel_string_list_new (TRUE);
 	
 	/* Populate the string picker */
 	for (i = 0; i < eel_enumeration_id_get_length (enumeration_id); i++) {
 		enum_description = eel_enumeration_id_get_nth_description_translated (enumeration_id, i);
 		g_assert (enum_description != NULL);
-		
+
 		if (enum_description[0] == '-') {
-			eel_string_picker_insert_separator (EEL_STRING_PICKER (child));
+			eel_string_list_insert (string_list, EEL_STRING_PICKER_SEPARATOR_STRING);
 		} else {
-			eel_string_picker_insert_string (EEL_STRING_PICKER (child), enum_description);
+			eel_string_list_insert (string_list, enum_description);
 		}
 		
 		g_free (enum_description);
 	}
  	g_free (enumeration_id);
 
+	eel_string_picker_set_string_list (EEL_STRING_PICKER (child), string_list);
+	eel_string_list_free (string_list);
+	
 	preferences_item_add_connection_child (item,
 					       child,
 					       "changed",
@@ -768,9 +783,13 @@ eel_preferences_item_new (const char *preference_name,
 	case EEL_PREFERENCE_ITEM_FONT:
 		preferences_item_create_font (item);
 		break;
-	
+
+	case EEL_PREFERENCE_ITEM_EDITABLE_PASSWORD_STRING:
+		preferences_item_create_editable_string (item, TRUE);
+		break;
+		
 	case EEL_PREFERENCE_ITEM_EDITABLE_STRING:
-		preferences_item_create_editable_string (item);
+		preferences_item_create_editable_string (item, FALSE);
 		break;	
 
 	case EEL_PREFERENCE_ITEM_EDITABLE_INTEGER:
@@ -845,8 +864,8 @@ enumeration_radio_changed_callback (EelRadioButtonGroup *radio_button_group,
 	g_return_if_fail (eel_strlen (enumeration_id) > 0);
 	g_return_if_fail ((guint)i < eel_enumeration_id_get_length (enumeration_id));
 	
-	eel_preferences_set_integer (item->details->preference_name,
-				     eel_enumeration_id_get_nth_value (enumeration_id, i));
+	eel_preferences_set_enum (item->details->preference_name,
+				  eel_enumeration_id_get_nth_value (enumeration_id, i));
 	g_free (enumeration_id);
 }
 
@@ -925,7 +944,7 @@ enumeration_menu_changed_callback (EelStringPicker *string_picker,
 	new_value = eel_enumeration_id_get_nth_value (enumeration_id,
 						      position);
 	
-	eel_preferences_set_integer (item->details->preference_name, new_value);
+	eel_preferences_set_enum (item->details->preference_name, new_value);
 
  	g_free (enumeration_id);
 }
@@ -1035,7 +1054,8 @@ preferences_item_update_displayed_value (EelPreferencesItem *item)
 	case EEL_PREFERENCE_ITEM_FONT:
 		preferences_item_update_font (item);
 		break;
-	
+
+	case EEL_PREFERENCE_ITEM_EDITABLE_PASSWORD_STRING:
 	case EEL_PREFERENCE_ITEM_EDITABLE_STRING:
 		preferences_item_update_editable_string (item);
 		break;	
@@ -1312,6 +1332,7 @@ eel_preferences_item_set_description (EelPreferencesItem *item,
 				    description);
 		break;
 	case EEL_PREFERENCE_ITEM_FONT:
+	case EEL_PREFERENCE_ITEM_EDITABLE_PASSWORD_STRING:
 	case EEL_PREFERENCE_ITEM_EDITABLE_STRING:
 	case EEL_PREFERENCE_ITEM_EDITABLE_INTEGER:
 	case EEL_PREFERENCE_ITEM_ENUMERATION_MENU:
